==> ideaIC-171.3224.1-sources.jar: com/intellij/ui/tabs/impl/DefaultEditorTabsPainter.java <==
/*
 * Copyright 2000-2017 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.ui.tabs.impl;

import com.intellij.openapi.util.registry.Registry;
import com.intellij.ui.ColorUtil;
import com.intellij.ui.Gray;
import com.intellij.ui.JBColor;
import com.intellij.util.ui.UIUtil;

import java.awt.*;

/**
 * @author Konstantin Bulenkov
 */
@SuppressWarnings("UseJBColor")
public class DefaultEditorTabsPainter extends JBEditorTabsPainter {

  @Override
  public void doPaintInactive(Graphics2D g2d,
                              Rectangle effectiveBounds,
                              int x,
                              int y,
                              int w,
                              int h,
                              Color tabColor,
                              int row,
                              int column,
                              boolean vertical) {
    ;
    g2d.setColor(tabColor != null ? tabColor : getDefaultTabColor());
    g2d.fillRect(x, y, w, h);
    if (Registry.is("ide.new.editor.tabs.selection")) return;
    g2d.setColor(getInactiveMaskColor());
    g2d.fillRect(x, y, w, h);
  }

  @Override
  public void doPaintBackground(Graphics2D g, Rectangle clip, boolean vertical, Rectangle rectangle) {
    g.setColor(Registry.is("ide.new.editor.tabs.selection") ? new JBColor(() -> UIUtil.getPanelBackground()) : getBackgroundColor());
    g.fill(clip);
  }

  public void fillSelectionAndBorder(Graphics2D g, JBTabsImpl.ShapeInfo selectedShape, Color tabColor, int x, int y, int height) {
    g.setColor(tabColor != null ? tabColor : getDefaultTabColor());
    g.fill(selectedShape.fillPath.getShape());
    //g.draw(selectedShape.fillPath.getShape());
  }

  @Override
  public Color getBackgroundColor() {
    return Registry.is("ide.new.editor.tabs.selection") ? new JBColor(Gray._255, Gray._60) : UIUtil.CONTRAST_BORDER_COLOR;
  }

  protected Color getDefaultTabColor() {
    if (myDefaultTabColor != null) {
      return myDefaultTabColor;
    }
    return Color.WHITE;
  }

  protected Color getInactiveMaskColor() {
    return ColorUtil.withAlpha(new Color(0x262626), .2);
  }
}

==> ideaIC-171.3566.24-sources.jar: com/intellij/ui/tabs/impl/DefaultEditorTabsPainter.java <==
/*
 * Copyright 2000-2017 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.ui.tabs.impl;

import com.intellij.ui.ColorUtil;
import com.intellij.ui.Gray;
import com.intellij.ui.JBColor;
import com.intellij.util.ui.UIUtil;

import java.awt.*;

/**
 * @author Konstantin Bulenkov
 */
@SuppressWarnings("UseJBColor")
public class DefaultEditorTabsPainter extends JBEditorTabsPainter {

  public DefaultEditorTabsPainter(JBEditorTabs tabs) {
    super(tabs);
  }

  @Override
  public void doPaintInactive(Graphics2D g2d,
                              Rectangle effectiveBounds,
                              int x,
                              int y,
                              int w,
                              int h,
                              Color tabColor,
                              int row,
                              int column,
                              boolean vertical) {
    ;
    g2d.setColor(tabColor != null ? tabColor : getDefaultTabColor());
    g2d.fillRect(x, y, w, h);
    if (myTabs.hasUnderlineSelection()) return;
    g2d.setColor(getInactiveMaskColor());
    g2d.fillRect(x, y, w, h);
  }

  @Override
  public void doPaintBackground(Graphics2D g, Rectangle clip, boolean vertical, Rectangle rectangle) {
    g.setColor(myTabs.hasUnderlineSelection() ? new JBColor(() -> UIUtil.getPanelBackground()) : getBackgroundColor());
    g.fill(clip);
  }

  public void fillSelectionAndBorder(Graphics2D g, JBTabsImpl.ShapeInfo selectedShape, Color tabColor, int x, int y, int height) {
    g.setColor(tabColor != null ? tabColor : getDefaultTabColor());
    g.fill(selectedShape.fillPath.getShape());
    //g.draw(selectedShape.fillPath.getShape());
  }

  @Override
  public Color getBackgroundColor() {
    return myTabs.hasUnderlineSelection() ? new JBColor(Gray._255, Gray._60) : UIUtil.CONTRAST_BORDER_COLOR;
  }

  protected Color getDefaultTabColor() {
    if (myDefaultTabColor != null) {
      return myDefaultTabColor;
    }
    return Color.WHITE;
  }

  protected Color getInactiveMaskColor() {
    return ColorUtil.withAlpha(new Color(0x262626), .2);
  }
}
